#[non_exhaustive]pub enum PollerContinuation {
Links {
next_link: Url,
final_link: Option<Url>,
},
}Expand description
Information returned by the server to poll subsequent status.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Links
Polling status or result is found at the following links.