PollerResult

Enum PollerResult 

pub enum PollerResult<M, F = JsonFormat>
where M: StatusMonitor, F: Format,
{ InProgress { response: Response<M, F>, retry_after: Duration, continuation: PollerContinuation, }, Done { response: Response<M, F>, }, Succeeded { response: Response<M, F>, target: Box<dyn FnOnce() -> Pin<Box<dyn Future<Output = Result<Response<<M as StatusMonitor>::Output, <M as StatusMonitor>::Format>>> + Send>> + Send>, }, }
The result of fetching the status monitor from a Poller, whether the long-running operation (LRO) is in progress or done.

Variants



InProgress

The long-running operation (LRO) is in progress and the next status monitor update may be fetched from continuation.

Fields

  • response contains the HTTP response with the status monitor.
  • retry_after is the optional client-specified Duration to wait. The default is 30 seconds.
  • continuation is the next link / continuation token.

Fields

response: Response<M, F>

The HTTP response with the status monitor.

retry_after: Duration

The optional client-specified Duration to wait before polling again.

continuation: PollerContinuation

The next link / continuation token.



Done

The long-running operation (LRO) succeeded and contains the final output.

Fields

  • response contains the HTTP response with the status monitor in a terminal state.

Fields

response: Response<M, F>

The HTTP response with the status monitor in a terminal state.



Succeeded

The long-running operation (LRO) succeeded and contains the final status.

Fields

  • response contains the HTTP response with the final status monitor.
  • get_target is an async function that fetches the final output.

Fields

response: Response<M, F>

The HTTP response with the final status monitor.

target: Box<dyn FnOnce() -> Pin<Box<dyn Future<Output = Result<Response<<M as StatusMonitor>::Output, <M as StatusMonitor>::Format>>> + Send>> + Send>

An async function that fetches the final output.