pub enum PollerResult<M, F = JsonFormat>where
M: StatusMonitor,
F: Format,{
InProgress {
response: Response<M, F>,
retry_after: Duration,
continuation: PollerContinuation,
},
Done {
response: Response<M, F>,
},
Succeeded {
response: Response<M, F>,
target: Box<dyn FnOnce() -> Pin<Box<dyn Future<Output = Result<Response<<M as StatusMonitor>::Output, <M as StatusMonitor>::Format>>> + Send>> + Send>,
},
}Expand description
The result of fetching the status monitor from a Poller, whether the long-running operation (LRO) is in progress or done.
Variants
InProgress
The long-running operation (LRO) is in progress and the next status monitor update may be fetched from continuation.
Fields
responsecontains the HTTP response with the status monitor.retry_afteris the optional client-specifiedDurationto wait. The default is 30 seconds.continuationis the next link / continuation token.
Fields

continuation: PollerContinuationThe next link / continuation token.
Done
The long-running operation (LRO) succeeded and contains the final output.
Fields
responsecontains the HTTP response with the status monitor in a terminal state.
Succeeded
The long-running operation (LRO) succeeded and contains the final status.
Fields
responsecontains the HTTP response with the final status monitor.get_targetis an async function that fetches the final output.